@@ -56,11 +56,6 @@ module Nanoc::CLI
       # Run
       yield
     rescue Exception => e # rubocop:disable Lint/RescueException
-      # The exception could be wrapped in a
-      # Nanoc::Core::Errors::CompilationError, so find the
-      # underlying exception and handle that one instead.
-      e = unwrap_error(e)
-
       case e
       when Interrupt
         puts
@@ -307,9 +302,9 @@ module Nanoc::CLI
     def write_error_detail(stream, error)
       error = unwrap_error(error)
 
-      if error.respond_to?(:full_message)
+      if error.respond_to?(:extended_message)
         stream.puts
-        stream.puts error.full_message
+        stream.puts error.extended_message
       end
     end
 
