@@ -10,18 +10,18 @@ module Nanoc
 
         affects_props :raw_content, :attributes, :compiled_content, :path
 
-        def apply(_obj, outdatedness_checker)
-          if any_snippets_modified?(outdatedness_checker)
+        def apply(_obj, basic_outdatedness_checker)
+          if any_snippets_modified?(basic_outdatedness_checker)
             Nanoc::Core::OutdatednessReasons::CodeSnippetsModified
           end
         end
 
         private
 
-        def any_snippets_modified?(outdatedness_checker)
-          outdatedness_checker.site.code_snippets.any? do |cs|
-            ch_old = outdatedness_checker.checksum_store[cs]
-            ch_new = outdatedness_checker.checksums.checksum_for(cs)
+        def any_snippets_modified?(basic_outdatedness_checker)
+          basic_outdatedness_checker.site.code_snippets.any? do |cs|
+            ch_old = basic_outdatedness_checker.checksum_store[cs]
+            ch_new = basic_outdatedness_checker.checksums.checksum_for(cs)
             ch_old != ch_new
           end
         end
