@@ -20,28 +20,28 @@ describe Nanoc::Core::CompilationItemRepView do
     Nanoc::Core::ViewContextForCompilation.new(
       reps: Nanoc::Core::ItemRepRepo.new,
       items: Nanoc::Core::ItemCollection.new(config),
-      dependency_tracker: dependency_tracker,
-      compilation_context: compilation_context,
-      compiled_content_store: compiled_content_store,
+      dependency_tracker:,
+      compilation_context:,
+      compiled_content_store:,
     )
   end
 
   let(:compilation_context) do
     Nanoc::Core::CompilationContext.new(
-      action_provider: action_provider,
-      reps: reps,
-      site: site,
-      compiled_content_cache: compiled_content_cache,
-      compiled_content_store: compiled_content_store,
+      action_provider:,
+      reps:,
+      site:,
+      compiled_content_cache:,
+      compiled_content_store:,
     )
   end
 
   let(:compiled_content_store) { Nanoc::Core::CompiledContentStore.new }
-  let(:compiled_content_cache) { Nanoc::Core::CompiledContentCache.new(config: config) }
+  let(:compiled_content_cache) { Nanoc::Core::CompiledContentCache.new(config:) }
 
   let(:site) do
     Nanoc::Core::Site.new(
-      config: config,
+      config:,
       code_snippets: [],
       data_source: Nanoc::Core::InMemoryDataSource.new(items, layouts),
     )
@@ -64,7 +64,7 @@ describe Nanoc::Core::CompilationItemRepView do
   it_behaves_like 'an item rep view'
 
   describe '#raw_path' do
-    subject { Fiber.new { view.raw_path }.resume }
+    subject { view.raw_path }
 
     let(:view) { described_class.new(rep, view_context) }
 
@@ -82,11 +82,11 @@ describe Nanoc::Core::CompilationItemRepView do
 
     context 'rep is not compiled' do
       it 'creates a dependency' do
-        expect { subject }.to change { dependency_store.objects_causing_outdatedness_of(base_item) }.from([]).to([item])
+        expect { subject rescue nil }.to change { dependency_store.objects_causing_outdatedness_of(base_item) }.from([]).to([item])
       end
 
       it 'creates a dependency with the right props' do
-        subject
+        subject rescue nil
         dep = dependency_store.dependencies_causing_outdatedness_of(base_item)[0]
 
         expect(dep.props.compiled_content?).to be(true)
@@ -96,7 +96,9 @@ describe Nanoc::Core::CompilationItemRepView do
         expect(dep.props.path?).to be(false)
       end
 
-      it { is_expected.to be_a(Nanoc::Core::Errors::UnmetDependency) }
+      it 'raises a dependency error' do
+        expect { subject }.to raise_error(Nanoc::Core::Errors::UnmetDependency)
+      end
     end
 
     context 'rep is compiled' do
