@@ -9,6 +9,7 @@ class Nanoc::Filters::RDocTest < Nanoc::TestCase
 
     # Run filter
     result = filter.setup_and_run('= Foo')
-    assert_match(%r{\A\s*<h1( id="label-Foo")?>Foo(<span>.*</span>)?</h1>\s*\Z}, result)
+
+    assert_match(%r{\A\s*<h1( id="label-Foo")?>.*Foo.*</h1>\s*\Z}, result)
   end
 end
